# Table of Contents

- [managing-resources-on-fact-sheet](<./managing-resources-on-fact-sheet.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Managing Fact Sheet Resources (GraphQL)](<./Managing-Fact-Sheet-Resources-GraphQL.md>)
  - [Creating a Resource on a Fact Sheet](<./Managing-Fact-Sheet-Resources-GraphQL/Creating-a-Resource-on-a-Fact-Sheet.md>)
  - [Retrieving Fact Sheet Resources](<./Managing-Fact-Sheet-Resources-GraphQL/Retrieving-Fact-Sheet-Resources.md>)
  - [Updating a Resource on a Fact Sheet](<./Managing-Fact-Sheet-Resources-GraphQL/Updating-a-Resource-on-a-Fact-Sheet.md>)
  - [Deleting a Resource from a Fact Sheet](<./Managing-Fact-Sheet-Resources-GraphQL/Deleting-a-Resource-from-a-Fact-Sheet.md>)
